FlutterEsimPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • FlutterEsimPlatform
Implementers

Constructors

FlutterEsimPlatform()
Constructs a FlutterEsimPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
onEvent → Stream
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

installEsimProfile(String profile) → Future<String>
instructions() → Future<String>
isSupportESim(List<String>? newer) → Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ FlutterEsimPlatform
The default instance of FlutterEsimPlatform to use.
getter/setter pair